# AniWorld Downloader

## Description

AniWorld Downloader is a command-line tool designed to download and stream content from aniworld.to.<br/>
It offers various features, including fetching single episodes, downloading entire seasons, organizing downloads into structured directories.<br/><br/>
It works on all three major operating systems (Windows, MacOS, Linux).

## Usage

> Install from pypi
```shell
pip install -U aniworld
```

> Run
```shell
aniworld
```

## Contributing

Contributions to AniWorld Downloader are welcome!
Feel free to submit bug reports, feature requests, or pull requests to help improve the project.

## License

This project is licensed under the MIT License. See the LICENSE file for more details.
